# Changelog

<!--next-version-placeholder-->

## v0.2.0 (2020-11-30)
### Feature
* Make the stack functions class methods ([`bf93c60`](https://github.com/kalekundert/tidyexc/commit/bf93c6084c3f33895cc2b28e1ef17c7c3fce0e18))
